@@ -8,6 +8,12 @@ utils::globalVariables(c("group_id",
                          "period_estimate",
                          "value",
                          "temp6",
+                         "gee",
+                         "acc",
+                         "pcc",
+                         "cohort",
+                         "crange",
+                         "ccc",
                          "."))
 # . age_estimate age_group as_tibble cohort_average cohort_group
 # coord_flip element_blank geom_abline geom_line geom_path geom_point
